flutter_mvu_test library
Classes
-
TestModelController<
T extends Object> -
A helper that wraps ModelController and exposes a
dispatch()method returning a Future that completes after the event has been applied and the state stream has emitted the new model.